@@ -3,14 +3,15 @@ Main interface for polly service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.polly import (
+    from mypy_boto3_polly import (
         Client,
         DescribeVoicesPaginator,
         ListLexiconsPaginator,
         ListSpeechSynthesisTasksPaginator,
         PollyClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -20,14 +21,17 @@ Usage::
     describe_voices_paginator: DescribeVoicesPaginator = client.get_paginator("describe_voices")
     list_lexicons_paginator: ListLexiconsPaginator = client.get_paginator("list_lexicons")
     list_speech_synthesis_tasks_paginator: ListSpeechSynthesisTasksPaginator = client.get_paginator("list_speech_synthesis_tasks")
+    ```
 """
-from mypy_boto3_polly.client import PollyClient, PollyClient as Client
-from mypy_boto3_polly.paginator import (
+from .client import PollyClient
+from .paginator import (
     DescribeVoicesPaginator,
     ListLexiconsPaginator,
     ListSpeechSynthesisTasksPaginator,
 )
 
+Client = PollyClient
+
 
 __all__ = (
     "Client",
